awaitReady abstract method

Future<void> awaitReady(
  1. DartReception reception
)
inherited

Complete once reception (a new Reception over connection) may be used: the Node shell posts a ready event when its process has booted; the native host booted its resident kernel and Peer Office when it started and posts no such event.

Implementation

Future<void> awaitReady(DartReception reception);